@@ -9,18 +9,30 @@ use Bytes::Random::Secure qw(
   random_bytes random_bytes_base64 random_bytes_hex
 );
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
+
+our $random;
+
+sub random {
+
+    my ($class) = @_;
+
+    unless ($random) {
+
+        $random = Bytes::Random::Secure->new(
+            Bits        => 64,
+            NonBlocking => 1,
+        );
+    }
+
+    return $random;
+}
 
 sub get_random_bits {
 
     my ( $class, $length ) = @_;
 
-    my $random = Bytes::Random::Secure->new(
-        Bits => 64,
-        NonBlocking => 1,
-    );
-
-    my $return =  Math::BigInt->from_bin( unpack( 'B*', $random->bytes(2) ) );
+    my $return = Math::BigInt->from_bin( unpack( 'B*', $class->random->bytes(2) ) );
 
     return $return;
 }
@@ -38,15 +50,14 @@ sub get_flake {
     my $self = shift;
 
     my $timestamp = $self->get_millisecond_timestamp;
-    my $random = $self->get_random_bits;
+    my $random    = $self->get_random_bits;
 
     my $flake = $timestamp->blsft(15);
     $flake->bior($random);
 
-    return substr( $flake->as_hex, 2);
+    return substr( $flake->as_hex, 2 );
 }
 
-
 1;
 __END__
 
